from django.core.mail import EmailMultiAlternatives, get_connection
from django.template.loader import get_template

from mdmail.api import EmailContent


def send_mail(subject, message, from_email, recipient_list, context=None, request=None, fail_silently=False,
              css=None, image_root='.', auth_user=None, auth_password=None, connection=None):
    connection = connection or get_connection(
        username=auth_user,
        password=auth_password,
        fail_silently=fail_silently,
    )
    if context is not None:
        message = get_template(message).render(context, request)
    content = EmailContent(message, css=css, image_root=image_root)
    mail = EmailMultiAlternatives(subject, content.text, from_email, recipient_list, connection=connection)
    mail.attach_alternative(content.html, 'text/html')

    return mail.send()



#!/usr/bin/env python

import os

from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

with open(os.path.join(os.path.dirname(__file__), 'requirements.in')) as requirements:
    REQUIREMENTS = [req.split('#egg=')[1] if '#egg=' in req else req for req in requirements.readlines()]


# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='dmdm',
    version='1.0.1',
    packages=['dmdm'],
    install_requires=REQUIREMENTS,
    include_package_data=True,
    license='BSD',
    description='Django MarkDown Mail',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/nim65s/dmdm',
    author='Guilhem Saurel',
    author_email='webmaster@saurel.me',
    python_requires='>=3',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
